@@ -18,7 +18,10 @@ class SSO:
     def __init__(self, sp_api_key, sp_hash_key, session_key) -> None:
         self.api = sp_api_key
         self.hash = sp_hash_key
-        self.check_credentials(sp_api_key, sp_hash_key, session_key)
+        self.session = session_key
+
+    def __call__(self):
+        return self.check_credentials(self.api, self.hash, self.session)
 
     @staticmethod
     def check_credentials(api_key: str, hash_key: str, session_key: str):
@@ -29,9 +32,10 @@ class SSO:
             headers = {
                 "api-key": api_key,
                 "hash-key":  hash_key,
-                "request-ts": int(time.time())
+                "request-ts": session_key
             }
-            response = requests.get(f"{URL}/{session_key}", headers=headers)
+            response = requests.get(
+                f"{URL}/v1/api/verify_sp/{session_key}", headers=headers)
             data = json.loads(response.text)
             return data
 
